# siterank
A python script to get alexa global rank for a given website or domain.

# Installation

	pip install siterank

# Usage

	> siterank google.com twitter.com linkedin.com www.upwork.com fiverr.com
	google.com 1
	twitter.com 11
	linkedin.com 25
	fiverr.com 301
	www.upwork.com 405
